; Hoftheater Kreuzberg e.V. Berlin 
; by Joan Manuel Piqueras Moreno
;
; CATT-Acoustic v8.0
;
; MAIN Program: MASTER.GEO
;===================================
;constant declarations =============================================

GLOBAL hd = 8.06		;hall depth
GLOBAL hw = 7.34/2		;hall width/2
GLOBAL hh = 4.76		;hall height

GLOBAL pbh =0.10		;prosc bottom wall height
GLOBAL psw =0.80		;prosc side wall width

GLOBAL sd = 4.90		;stage depth
GLOBAL sw = 5.74/2		;stage width/2 
GLOBAL sh = 3.96		;stage height   

GLOBAL as = 1.06		;pit audience-stage
GLOBAL ah = 2.40		;max. stalls height
GLOBAL ccr = 1.1/2		;central corridor/2
GLOBAL aud = 0.85		;audience height

; ==================================================================

;absorption and scattering coefficients 125Hz to 4kHz [%], RGB-color 
ABS mtseat_fab = <19 37 56 67 61 59> 		   	    { 153 214 41 }
ABS public_tnc = <38 60 80 90 90 90> 			    { 153 214 41 }
ABS wood     = <15 11 10 7 6 7> 			    { 159 152 96 }
ABS parquet  = <2 15 10 8 5 5>				    { 126 82 0 }
ABS cirrus   = <30 31 42 54 64 66>			    { 228 179 27 }
ABS drape_thin = <4 5 11 18 30 35>			    { 0 74 126 }
ABS drape_thin2 = <4 5 11 18 30 35>			    { 244 85 22 }
ABS velour_LT = <3 4 11 17 24 35>			    { 24 35 87 }
ABS woodpanel_16 = <20 12 10 10 8 7>		 	    { 126 0 120 }
ABS resonador_TRR9 = <95 65 20 19 17 16>		    { 94 119 162 }

;matt assignements =================================================
ABS ceilstage = cirrus
ABS ceilhall = woodpanel_16
ABS audience_unocc = mtseat_fab
ABS audience_occ = public_tnc
ABS floor = parquet
ABS stageflr = wood
ABS wallstage = velour_LT
ABS prosc = drape_thin2
ABS wallhall = drape_thin
ABS wallrear = woodpanel_16
ABS back = resonador_TRR9

;Notes:
;- if 8k and 16k values are known they can be given after 
;  a colon as in <15 13 10  9   8   7 : 7 8 > otherwise they
;  are extrapolated from 2k and 4k values.
;- color is optional, one will be auto generated if not given.
;- scattering coefficients are optional (but strongly recommended)
;  if not given the default values in General settings will be used
; ==================================================================

CORNERS

; HALL =========================== 
;floor corners
 1	-hw	0	0
 2	-hw	hd	0
 3	 hw	hd	0
 4	 hw	0	0

;ceiling corners
11	-hw	0	hh
12	-hw	hd	hh
13	 hw	hd	hh
14	 hw	0	hh

; STAGE ==========================
;floor corners
21	-sw	0	pbh
22	-sw	-sd	pbh
23	 sw	-sd	pbh
24	 sw	0	pbh

;ceiling corners
31	-sw	0	sh
32	-sw	-sd	sh
33	 sw	-sd	sh
34	 sw	0	sh

; PROSC ==========================
;left corners
41	-hw	0	pbh
51	-hw	0	sh

;right corners
44	 hw	0	pbh
54	 hw	0	sh

; STALLS =========================
;right stalls
5	-hw+0.6	as	0
6	-hw+0.6	hd-1	0
7	-ccr	hd-1	0
8	-ccr	as	0
9	-ccr	hd-1	ah	
10	-hw+0.6	hd-1	ah

;left stalls
15	hw-0.6	as	0
16	hw-0.6	hd-1	0
17	ccr	hd-1	0
18	ccr	as	0
19	ccr	hd-1	ah
20	hw-0.6	hd-1	ah

; STAIRS =========================
;right stairs
35	-hw	as	0
36	-hw	hd-1	0
37	-hw	hd-1	ah

;left stairs
46	hw	as	0
47	hw	hd-1	0
48	hw	hd-1	ah

; TECHNICIANS ====================
;technicians and public
25	-hw	hd	ah
26	-ccr	hd	ah
27	ccr	hd	ah
28	hw	hd	ah
29	-hw+0.6	hd	ah
30	hw-0.6	hd	ah

;technicians wall
55	-ccr	hd-1	ah+0.9
56	ccr	hd-1	ah+0.9
57	ccr	hd-0.6	ah
58 	-ccr	hd-0.6	ah

; AUDIENCE =======================
; right side
60	-hw+0.6	as	aud
61	-hw+0.6	hd-1	ah+aud
62	-hw+0.6	hd	ah+aud
63	-ccr	hd	ah+aud
64	-ccr	hd-1	ah+aud	
65	-ccr	as	aud

; left side
66	hw-0.6	as	aud
67	hw-0.6	hd-1	ah+aud
68	hw-0.6	hd	ah+aud
69	ccr	hd	ah+aud
70	ccr	hd-1	ah+aud
71	ccr	as	aud

;==========================================
PLANES

; HALL ====================================
[1 floor / 4 3 2 1 / floor ]		
[2 ceiling / 11 12 13 14 / ceilhall ]  	
[3 rear wall / 3 13 12 2 / wallrear ]
[4 left wall / 2 12 11 1 / wallhall ]
[5 right wall / 4 14 13 3 / wallhall ]

; STAGE ===================================
[6 floor stage / 23 24 21 22 / stageflr ]
[7 ceiling stage / 32 31 34 33 / ceilstage ]
[8 rear wall stage / 22 32 33 23 / wallstage ]
[9 left wall stage / 21 31 32 22 / wallstage ]
[10 right wall stage / 23 33 34 24 / wallstage ]

; PROSC ===================================
[11 floor prosc / 1 41 44 4  / stageflr ]
[12 top prosc / 51 11 14 54 / prosc ]
[13 left prosc / 41 51 31 21 / prosc ]
[14 right prosc / 24 34 54 44 / prosc ]

; STALLS ==================================
;right stalls
[15 floor right stalls \ 8 7 6 5 \ wood ]
[16 ceiling right stalls / 8 9 10 5 / wood ]  ;Right-Audience
[17 rear right stalls / 10 9 7 6 / wood ]
[18 leftwall right stalls / 6 10 5 / wood ]
[19 rightwall right stalls / 8 7 9 / wood ]

;left stalls
[20 floor leftt stalls / 18 17 16 15 / wood ]
[21 ceiling left stalls / 15 20 19 18 / wood ] ;Left-Audience
[22 rear left stalls / 17 19 20 16 / wood ]
[23 leftwall left stalls / 16 20 15 / wood ]
[24 rightwall left stalls / 18 19 17 / wood ]

; STAIRS ==================================
;right stairs
[25 floor right stairs \ 6 36 35 5 \ wood ]
[26 ceiling right stairs \ 35 37 10 5 \ wood ]
[27 rear right stairs / 10 6 36 37 / wood ]
[28 leftwall right stairs \ 37 35 36 \ wood ]

;left stairs
[29 floor left stairs / 16 47 46 15 / wood ]
[30 ceiling left stairs / 15 46 48 20 / wood ] ;18 46 48 19
[31 rear left stairs / 48 47 16 20 / wood ]
[32 rightwall left stairs / 47 48 46 / wood ]

; TECHNICIANS =============================
[33 floor tech / 48 28 25 37 / wood ]
[34 floor right stalls / 29 10 9 26 / wood ] ;Audience 
[35 floor left stalls / 20 30 27 19 / wood ] ;Audience

;panel protector tech
[36 wall tech / 19 56 55 9 / back ]	;Wall with absorption
[37 left wall tech / 9 58 55 / wood ]	
[38 right wall tech / 19 57 56 / wood ]

; AUDIENCE ================================ 
;audience_occ = occupied
;audience_unocc = unoccupied

;right side		
[39 top rs / 65 64 61 60 / audience_occ ]
[40 top2 rs / 62 61 64 63 / audience_occ ]
[41 front rs / 65 60 5 8 / audience_occ ]
[42 rear rs / 63 26 29 62 / audience_occ ]
[43 left rs / 5 60 61 10 / audience_occ ]
[44 left2 rs / 10 61 62 29 / audience_occ ]
[45 right rs / 65 8 9 64 / audience_occ ]
[46 right2 rs / 64 9 26 63 / audience_occ ]

;left side
[47 top ls / 66 67 70 71 / audience_occ ]
[48 top2 ls / 67 68 69 70 / audience_occ ]
[49 front ls / 71 18 15 66 / audience_occ ]
[50 rear ls / 68 30 27 69 / audience_occ ]
[51 left ls / 18 71 70 19 / audience_occ ]
[52 left2 ls / 69 27 19 70 / audience_occ ]
[53 right ls / 66 15 20 67 / audience_occ ]
[54 right2 ls / 67 20 30 68 / audience_occ ] 

